@@ -7,7 +7,7 @@ use warnings;
 # section.
 
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 1;
@@ -15,30 +15,43 @@ our $VERSION = '0.02';
 
 __END__
 
+
+
 =head1 NAME
 
 Class::Scaffold - large-scale OOP application support
 
 =head1 SYNOPSIS
 
-None yet (see below).
+    Class::Scaffold->new;
 
 =head1 DESCRIPTION
 
-None yet. This is an early release; fully functional, but undocumented. The
-next release will have more documentation.
+=head1 METHODS
+
+=over 4
+
+
+
+=back
+
+Class::Scaffold inherits from .
 
 =head1 TAGS
 
 If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<classframework> tag.
+please use the C<classscaffold> tag.
+
+=head1 VERSION 
+                   
+This document describes version 0.03 of L<Class::Scaffold>.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-class-framework@rt.cpan.org>, or through the web interface at
+C<<bug-class-scaffold@rt.cpan.org>>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -65,10 +78,11 @@ Heinz Ekker C<< <ek@univie.ac.at> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by Marcel GrE<uuml>nauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+
 =cut
 
