@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 use base 'Class::Factory::Enhanced';
@@ -19,30 +19,56 @@ sub factory_log {}
 
 __END__
 
+
+
 =head1 NAME
 
-Class::Scaffold - large-scale OOP application support
+Class::Scaffold::Factory::Type - large-scale OOP application support
 
 =head1 SYNOPSIS
 
-None yet (see below).
+    Class::Scaffold::Factory::Type->new;
 
 =head1 DESCRIPTION
 
-None yet. This is an early release; fully functional, but undocumented. The
-next release will have more documentation.
+=head1 METHODS
+
+=over 4
+
+
+
+=back
+
+Class::Scaffold::Factory::Type inherits from L<Class::Factory::Enhanced>.
+
+The superclass L<Class::Factory::Enhanced> defines these methods and
+functions:
+
+    add_factory_type(), make_object_for_type(), register_factory_type()
+
+The superclass L<Class::Factory> defines these methods and functions:
+
+    new(), factory_error(), get_factory_class(), get_factory_type_for(),
+    get_loaded_classes(), get_loaded_types(), get_my_factory(),
+    get_my_factory_type(), get_registered_class(),
+    get_registered_classes(), get_registered_types(), init(),
+    remove_factory_type(), unregister_factory_type()
 
 =head1 TAGS
 
 If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<classframework> tag.
+please use the C<classscaffold> tag.
+
+=head1 VERSION 
+                   
+This document describes version 0.03 of L<Class::Scaffold::Factory::Type>.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-class-framework@rt.cpan.org>, or through the web interface at
+C<<bug-class-scaffold@rt.cpan.org>>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -69,10 +95,11 @@ Heinz Ekker C<< <ek@univie.ac.at> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by Marcel GrE<uuml>nauer
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+
 =cut
 
